# registry

```{eval-rst}
.. automodule:: engunits.registry
   :members:
   :undoc-members:
   :exclude-members: ureg

.. data:: ureg
   :type: pint.UnitRegistry

   Application-wide unit registry instance.
```
